pub(super) trait CameraViewfinderImpl: ObjectImpl { }Expand description
Trait that must be implemented for types that subclass CameraViewfinder.
Overriding a method from this Trait overrides also its behavior in
CameraViewfinderExt.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.